Client

Struct Client 

pub struct Client { /* private fields */ }
Client for RunMat Server API

Version: 0.2.8

Implementations

Source

impl Client

pub fn new(baseurl: &str) -> Self

Create a new client.

baseurl is the base URL provided to the internal reqwest::Client, and should include a scheme and hostname, as well as port and a path stem if applicable.

pub fn new_with_client(baseurl: &str, client: Client) -> Self

Construct a new client with an existing reqwest::Client, allowing more control over its configuration.

baseurl is the base URL provided to the internal reqwest::Client, and should include a scheme and hostname, as well as port and a path stem if applicable.

Source

impl Client

pub async fn auth_me<'a>( &'a self, ) -> Result<ResponseValue<AuthMeResponse>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/auth/me

pub async fn auth_resend_verification<'a>( &'a self, body: &'a AuthResendVerificationRequest, ) -> Result<ResponseValue<AuthResendVerificationResponse>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/auth/resend-verification

pub async fn auth_resolve<'a>( &'a self, body: &'a AuthResolveRequest, ) -> Result<ResponseValue<AuthResolveResponse>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/auth/resolve

pub async fn submit_web_intake<'a>( &'a self, body: &'a WebIntakeRequest, ) -> Result<ResponseValue<WebIntakeResponse>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/lifecycle/intake

pub async fn list_orgs<'a>( &'a self, cursor: Option<&'a str>, limit: Option<u64>, ) -> Result<ResponseValue<OrgListResponse>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/orgs

pub async fn create_org<'a>( &'a self, body: &'a OrgCreateRequest, ) -> Result<ResponseValue<ServerOrgOrg>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/orgs

pub async fn get_policy<'a>( &'a self, org_id: &'a str, ) -> Result<ResponseValue<PolicyResponse>, Error<()>>

Sends a GET request to /v1/orgs/{orgId}/policy

pub async fn list_projects<'a>( &'a self, org_id: &'a str, cursor: Option<&'a str>, limit: Option<u64>, ) -> Result<ResponseValue<ProjectListResponse>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/orgs/{orgId}/projects

pub async fn create_project<'a>( &'a self, org_id: &'a str, body: &'a ProjectCreateRequest, ) -> Result<ResponseValue<ServerOrgProject>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/orgs/{orgId}/projects

pub async fn create_project_import<'a>( &'a self, org_id: &'a str, body: &'a ProjectImportGitRequest, ) -> Result<ResponseValue<ProjectImportGitResponse>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/orgs/{orgId}/projects/import-git

pub async fn create_upgrade_request<'a>( &'a self, org_id: &'a str, body: &'a UpgradeRequestCreateRequest, ) -> Result<ResponseValue<UpgradeRequestCreateResponse>, Error<()>>

Sends a POST request to /v1/orgs/{orgId}/upgrade-request

pub async fn get_usage<'a>( &'a self, org_id: &'a str, end: Option<&'a str>, start: Option<&'a str>, ) -> Result<ResponseValue<UsagePeriodResponse>, Error<()>>

Sends a GET request to /v1/orgs/{orgId}/usage

pub async fn list_usage_notices<'a>( &'a self, org_id: &'a str, ) -> Result<ResponseValue<Vec<UsageNoticeResponse>>, Error<()>>

Sends a GET request to /v1/orgs/{orgId}/usage/notices

pub async fn usage_rollup_event<'a>( &'a self, org_id: &'a str, body: &'a UsageRollupRequest, ) -> Result<ResponseValue<ByteStream>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/orgs/{orgId}/usage/rollup

pub async fn chunk_upload_targets<'a>( &'a self, project_id: &'a str, body: &'a DataChunkUploadTargetsRequest, ) -> Result<ResponseValue<DataChunkUploadTargetsResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/data/chunks/upload-targets

pub async fn manifest<'a>( &'a self, project_id: &'a str, path: &'a str, version: Option<&'a str>, ) -> Result<ResponseValue<DataManifestDescriptorResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/data/manifest

pub async fn canonicalize<'a>( &'a self, project_id: &'a str, path: &'a str, ) -> Result<ResponseValue<FsPathQuery>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/canonicalize

pub async fn commit<'a>( &'a self, project_id: &'a str, body: &'a FsCommitRequest, ) -> Result<ResponseValue<FsCommitResponse>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/projects/{projectId}/fs/commit

pub async fn list_dir<'a>( &'a self, project_id: &'a str, path: &'a str, ) -> Result<ResponseValue<Vec<FsDirEntry>>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/projects/{projectId}/fs/dir

pub async fn delete_dir<'a>( &'a self, project_id: &'a str, path: &'a str, recursive: Option<bool>, ) -> Result<ResponseValue<ByteStream>, Error<CrateErrorsErrorResponse>>

Sends a DELETE request to /v1/projects/{projectId}/fs/dir

pub async fn download_url<'a>( &'a self, project_id: &'a str, path: &'a str, version_id: Option<&'a str>, ) -> Result<ResponseValue<FsDownloadUrlResponse>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/projects/{projectId}/fs/download-url

pub async fn delete_file<'a>( &'a self, project_id: &'a str, path: &'a str, ) -> Result<ResponseValue<ByteStream>, Error<CrateErrorsErrorResponse>>

Sends a DELETE request to /v1/projects/{projectId}/fs/file

pub async fn git_receive<'a, B: Into<Body>>( &'a self, project_id: &'a str, body: B, ) -> Result<ResponseValue<ByteStream>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/git/receive

pub async fn git_refs<'a>( &'a self, project_id: &'a str, ) -> Result<ResponseValue<FsGitRefsResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/git/refs

pub async fn git_upload<'a>( &'a self, project_id: &'a str, ) -> Result<ResponseValue<ByteStream>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/git/upload

pub async fn delete_history_version<'a>( &'a self, project_id: &'a str, version_id: &'a str, ) -> Result<ResponseValue<()>, Error<()>>

Sends a DELETE request to /v1/projects/{projectId}/fs/history/{versionId}

pub async fn manifest_get_v1_projects_project_id_fs_manifest<'a>( &'a self, project_id: &'a str, path: &'a str, version_id: Option<&'a str>, ) -> Result<ResponseValue<FsManifestResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/manifest

pub async fn manifest_history<'a>( &'a self, project_id: &'a str, path: &'a str, ) -> Result<ResponseValue<FsManifestHistoryResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/manifest/history

pub async fn manifest_update<'a>( &'a self, project_id: &'a str, body: &'a FsManifestUpdateRequest, ) -> Result<ResponseValue<FsCommitResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/manifest/update

pub async fn manifest_urls<'a>( &'a self, project_id: &'a str, path: &'a str, version_id: Option<&'a str>, ) -> Result<ResponseValue<FsManifestUrlsResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/manifest/urls

pub async fn metadata<'a>( &'a self, project_id: &'a str, path: &'a str, ) -> Result<ResponseValue<FsMetadataResponse>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/projects/{projectId}/fs/metadata

pub async fn mkdir<'a>( &'a self, project_id: &'a str, body: &'a FsMkdirRequest, ) -> Result<ResponseValue<ByteStream>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/projects/{projectId}/fs/mkdir

pub async fn read<'a>( &'a self, project_id: &'a str, length: Option<i64>, offset: i64, path: &'a str, ) -> Result<ResponseValue<ByteStream>, Error<CrateErrorsErrorResponse>>

Reads file bytes from the project filesystem. This endpoint also accepts

readonly reference paths like reference:runmat/docs/search.md, resolving them through the bound RunMat reference variant.

Sends a GET request to /v1/projects/{projectId}/fs/read

pub async fn rename<'a>( &'a self, project_id: &'a str, body: &'a FsRenameRequest, ) -> Result<ResponseValue<ByteStream>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/projects/{projectId}/fs/rename

pub async fn get_retention<'a>( &'a self, project_id: &'a str, ) -> Result<ResponseValue<FsRetentionResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/retention

pub async fn update_retention<'a>( &'a self, project_id: &'a str, body: &'a FsRetentionUpdateRequest, ) -> Result<ResponseValue<FsRetentionResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/retention

pub async fn index<'a>( &'a self, project_id: &'a str, artifact_root: Option<&'a str>, cursor: Option<&'a str>, doc_path: Option<&'a str>, include: Option<&'a str>, limit: Option<u64>, ) -> Result<ResponseValue<FsRunsIndexResponse>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/projects/{projectId}/fs/runs/index

pub async fn set_readonly<'a>( &'a self, project_id: &'a str, body: &'a FsSetReadonlyRequest, ) -> Result<ResponseValue<ByteStream>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/projects/{projectId}/fs/set-readonly

pub async fn list_snapshots<'a>( &'a self, project_id: &'a str, ) -> Result<ResponseValue<FsSnapshotListResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/snapshots

pub async fn create_snapshot<'a>( &'a self, project_id: &'a str, body: &'a FsSnapshotCreateRequest, ) -> Result<ResponseValue<FsSnapshotResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/snapshots

pub async fn list_snapshot_tags<'a>( &'a self, project_id: &'a str, ) -> Result<ResponseValue<FsSnapshotTagListResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/snapshots/tags

pub async fn delete_snapshot_tag<'a>( &'a self, project_id: &'a str, tag: &'a str, ) -> Result<ResponseValue<ByteStream>, Error<()>>

Sends a DELETE request to /v1/projects/{projectId}/fs/snapshots/tags/{tag}

pub async fn delete_snapshot<'a>( &'a self, project_id: &'a str, snapshot_id: &'a str, ) -> Result<ResponseValue<ByteStream>, Error<()>>

Sends a DELETE request to /v1/projects/{projectId}/fs/snapshots/{snapshotId}

pub async fn snapshot_diff<'a>( &'a self, project_id: &'a str, snapshot_id: &'a str, base_snapshot_id: Option<&'a str>, compare_to_current: Option<bool>, ) -> Result<ResponseValue<FsSnapshotDiffResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/snapshots/{snapshotId}/diff

pub async fn list_snapshot_entries<'a>( &'a self, project_id: &'a str, snapshot_id: &'a str, ) -> Result<ResponseValue<FsSnapshotEntryListResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/snapshots/{snapshotId}/entries

pub async fn snapshot_git_export<'a>( &'a self, project_id: &'a str, snapshot_id: &'a str, ) -> Result<ResponseValue<ByteStream>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/snapshots/{snapshotId}/git-export

pub async fn restore_snapshot<'a>( &'a self, project_id: &'a str, snapshot_id: &'a str, body: Option<&'a FsSnapshotRestoreRequest>, ) -> Result<ResponseValue<ByteStream>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/snapshots/{snapshotId}/restore

pub async fn set_snapshot_tag<'a>( &'a self, project_id: &'a str, snapshot_id: &'a str, body: &'a FsSnapshotTagRequest, ) -> Result<ResponseValue<FsSnapshotTagResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/snapshots/{snapshotId}/tags

pub async fn storage_summary<'a>( &'a self, project_id: &'a str, artifact_root: Option<&'a str>, ) -> Result<ResponseValue<FsStorageSummaryResponse>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/projects/{projectId}/fs/storage-summary

pub async fn delete_storage_category<'a>( &'a self, project_id: &'a str, body: &'a FsStorageDeleteCategoryRequest, ) -> Result<ResponseValue<FsStorageDeleteCategoryResponse>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/projects/{projectId}/fs/storage/delete-category

pub async fn upload_session<'a>( &'a self, project_id: &'a str, body: &'a FsUploadSessionRequest, ) -> Result<ResponseValue<FsUploadSessionResponse>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/projects/{projectId}/fs/upload-session

pub async fn upload_session_abort<'a>( &'a self, project_id: &'a str, body: &'a FsUploadSessionAbortRequest, ) -> Result<ResponseValue<FsUploadSessionAbortResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/upload-session/abort

pub async fn upload_session_chunks<'a>( &'a self, project_id: &'a str, body: &'a FsUploadSessionChunksRequest, ) -> Result<ResponseValue<FsUploadSessionChunksResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/upload-session/chunks

pub async fn upload_session_complete<'a>( &'a self, project_id: &'a str, body: &'a FsUploadSessionCompleteRequest, ) -> Result<ResponseValue<FsCommitResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/upload-session/complete

pub async fn upload_session_keepalive<'a>( &'a self, project_id: &'a str, body: &'a FsUploadSessionKeepaliveRequest, ) -> Result<ResponseValue<FsUploadSessionKeepaliveResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/upload-session/keepalive

pub async fn upload_session_start<'a>( &'a self, project_id: &'a str, body: &'a FsUploadSessionStartRequest, ) -> Result<ResponseValue<FsUploadSessionStartResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/fs/upload-session/start

pub async fn upload_session_status<'a>( &'a self, project_id: &'a str, session_id: &'a str, blob_key: &'a str, ) -> Result<ResponseValue<FsUploadSessionStatusResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/fs/upload-session/{sessionId}

pub async fn write<'a>( &'a self, project_id: &'a str, final_: Option<bool>, hash: Option<&'a str>, offset: i64, path: &'a str, truncate: bool, ) -> Result<ResponseValue<FsCommitResponse>, Error<CrateErrorsErrorResponse>>

Sends a PUT request to /v1/projects/{projectId}/fs/write

pub async fn list_history<'a>( &'a self, project_id: &'a str, path: &'a str, ) -> Result<ResponseValue<FsHistoryListResponse>, Error<()>>

Sends a GET request to /v1/projects/{projectId}/history

pub async fn restore_history<'a>( &'a self, project_id: &'a str, body: &'a FsHistoryRestoreRequest, ) -> Result<ResponseValue<FsCommitResponse>, Error<()>>

Sends a POST request to /v1/projects/{projectId}/history/restore

pub async fn get_project_import_status<'a>( &'a self, project_id: &'a str, ) -> Result<ResponseValue<Option<ProjectImportStatusResponse>>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/projects/{projectId}/import

pub async fn list_project_memberships<'a>( &'a self, project_id: &'a str, cursor: Option<&'a str>, limit: Option<u64>, ) -> Result<ResponseValue<ProjectMembershipListResponse>, Error<CrateErrorsErrorResponse>>

Sends a GET request to /v1/projects/{projectId}/memberships

pub async fn create_project_membership<'a>( &'a self, project_id: &'a str, body: &'a ProjectMembershipCreateRequest, ) -> Result<ResponseValue<ServerOrgProjectMembership>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/projects/{projectId}/memberships

pub async fn delete_project_membership<'a>( &'a self, project_id: &'a str, membership_id: &'a str, ) -> Result<ResponseValue<ByteStream>, Error<CrateErrorsErrorResponse>>

Sends a DELETE request to /v1/projects/{projectId}/memberships/{membershipId}

pub async fn update_project_membership<'a>( &'a self, project_id: &'a str, membership_id: &'a str, body: &'a ProjectMembershipUpdateRequest, ) -> Result<ResponseValue<ServerOrgProjectMembership>, Error<CrateErrorsErrorResponse>>

Sends a PATCH request to /v1/projects/{projectId}/memberships/{membershipId}

pub async fn ingest_telemetry<'a>( &'a self, body: &'a TelemetryIngestRequest, ) -> Result<ResponseValue<TelemetryIngestResponse>, Error<CrateErrorsErrorResponse>>

Sends a POST request to /v1/t